@@ -36,6 +36,7 @@ import getpass
 import subprocess
 import re
 import textwrap
+import platform
 from mlhub.utils import yes_or_no
 
 
@@ -112,7 +113,7 @@ That information has been saved into the file:
             with open(key_file, 'r') as handle:
                 parsed = json.load(handle)
             print(f"\n{json.dumps(parsed, indent=2)}")
-            yes = yes_or_no("\nUse this private information ",
+            yes = yes_or_no("\nUse this private information "
                             "(type 'n' to update)")
 
         if not yes:
@@ -230,12 +231,48 @@ def azrequest(endpoint, url, subscription_key, request_data):
         raise Exception(response.text)
 
 
+def get_char():
+    # From https://stackoverflow.com/questions/510357/
+    # how-to-read-a-single-character-from-the-user
+    # try to bypass python input()
+    if is_windows():
+        # For Windows-based systems
+        import msvcrt  # If successful, we are on Windows
+        return msvcrt.getch()
+    else:
+        # For POSIX-based systems (with termios & tty support)
+        import tty
+        import sys
+        import termios  # Raises ImportError if unsupported.
+
+        fd = sys.stdin.fileno()
+        oldSettings = termios.tcgetattr(fd)
+
+        try:
+            tty.setcbreak(fd)
+            answer = sys.stdin.read(1)
+        finally:
+            termios.tcsetattr(fd, termios.TCSADRAIN, oldSettings)
+
+        return answer
+
+
 def mlask(prompt="Press Enter to continue", begin="", end=""):
-    begin = "\n" if begin else begin
-    end = "\n" if end else end
+    begin = "\n" if isinstance(begin, bool) and begin else begin
+    end = "\n" if isinstance(end, bool) and end else end
+
+    if isinstance(prompt, bool):
+        sys.stderr.write("\n**Warning**\n"
+                         "mlhub.pkg.mlask() parameter order updated.\n"
+                         "Ignoring begin setting for now.\n"
+                         "The source mlhub package needs to be updated."
+                         "\n")
+        prompt = "Press Enter to continue"
+
     sys.stdout.write(begin + prompt + ": ")
-    input()
-    sys.stdout.write(end)
+    sys.stdout.flush()
+    get_char()
+    sys.stdout.write(end + "\n")
 
 
 def mlcat(title="", text="", delim="=", begin="", end="\n"):
@@ -255,10 +292,28 @@ def mlcat(title="", text="", delim="=", begin="", end="\n"):
 def mlpreview(fname,
               begin="\n",
               msg="Close the graphic window using Ctrl-W.\n",
-              previewer="eog"):
+              previewer=None):
     print(begin + msg)
-    subprocess.Popen([previewer, fname])
+    if is_linux():
+        if previewer is None:
+            # Linux desktop default application for the file.
+            previewer = "xdg-open"
+        subprocess.Popen([previewer, fname])
+    elif is_windows():
+        # Windows automatically uses default program based on file extension.
+        subprocess.Popen(["start", fname], shell=True)
+    else:
+        if previewer is None:
+            previewer = "open"  # Perhaps a Mac?
+        subprocess.Popen([previewer, fname])
 
+        
+def is_linux():
+    return platform.system() == "Linux"
+
+
+def is_windows():
+    return platform.system() == "Windows"
 
 # From Simon Zhao's azface package on github.
 
@@ -268,7 +323,7 @@ def is_url(url):
 
     urlregex = re.compile(
         r'^(?:http|ftp)s?://'  # http:// or https://
-        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+
+        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+'
         r'(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
         r'localhost|'  # localhost...
         r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
